@@ -1,5 +1,7 @@
 from apimatic_core_interfaces.types.authentication import Authentication
 
+from apimatic_core.utilities.auth_helper import AuthHelper
+
 
 class HeaderAuth(Authentication):
 
@@ -8,9 +10,8 @@ class HeaderAuth(Authentication):
         self._error_message = None
 
     def is_valid(self):
-        return self._auth_params and all(param and self._auth_params[param] for param in self._auth_params)
+        return AuthHelper.is_valid_auth(self._auth_params)
 
     def apply(self, http_request):
-        for param in self._auth_params:
-            http_request.add_header(param, self._auth_params[param])
+        AuthHelper.apply(self._auth_params, http_request.add_header)
 
